@@ -1,9 +1,16 @@
 SOC <-
-function(n=NA,a=NA,d=NA,h=NA,m=NA,r=NA,b=NA,model=c("EOQ","EPQ"),cooperation=c(0,1)){
-coalicion<-coalitions(n)
-matriz<-as.matrix(coalicion[[1]])
-matriz0<-matriz
-matrizcostes<-matriz
+function(n=NA,a=NA,d=NA,h=NA,m=NA,r=NA,b=NA,model=c("EOQ","EPQ")){
+  
+cooperation=1
+if (n<=10){
+  coalicion<-coalitions(n)
+  matriz<-as.matrix(coalicion[[1]])
+  matriz0<-matriz
+  matrizcostes<-matriz
+}
+if (n>10){
+  matriz0<-c();matrizcostes<-c()
+}
 
 if (sum(is.na(h)==T)==length(h)){
   cat("A value for h is necessary to determinate the optimal orders.", sep="\n")
@@ -26,14 +33,23 @@ if (sum(is.na(d)!=T)==length(d)&length(Q)==n){m=d/Q}
 
 
 if (sum(is.na(m)!=T)==length(m)){
-if (cooperation==0){coste<-2*a*m}
+if (cooperation==0){
+  cat("Non-cooperative case. The allocation proposed by the SOC rule corresponds to the individual costs.", sep="\n")
+  
+  coste<-2*a*m
+  }
 if (cooperation==1){
-  for (i in 2:nrow(matriz0)){
-    aux<-which(matriz0[i,]!=0)
-    for (j in 1:length(aux)){
-      matrizcostes[i,aux[j]]<-2*a*m[aux[j]]^2/sqrt(sum(m[aux]^2))
+  if (n<=10){
+    for (i in 2:nrow(matriz0)){
+      aux<-which(matriz0[i,]!=0)
+      for (j in 1:length(aux)){
+        matrizcostes[i,aux[j]]<-2*a*m[aux[j]]^2/sqrt(sum(m[aux]^2))
+      }
     }
-}
+  }
+  if (n>10){
+    matrizcostes<-2*a*m^2/sqrt(sum(m^2))
+  }
 }
 
 if (cooperation==0){
@@ -41,10 +57,21 @@ sol<-list(coste)
 names(sol)<-c("Share the ordering costs rule (individually)")
 }
 if (cooperation==1){
-colnames(matrizcostes)<-1:n
-rownames(matrizcostes)<-rep(" ",2^n)
-sol<-list(matrizcostes)
-
+  
+  
+  if (n<=10){
+    rownames(matrizcostes)<-rep(" ",2^n)
+    colnames(matrizcostes)<-1:n
+    sol<-list(matrizcostes)
+  }
+  if (n>10){
+    matrizcostes<-t(as.matrix(matrizcostes))
+    rownames(matrizcostes)<-""
+    colnames(matrizcostes)<-1:n
+    
+    sol<-list(matrizcostes)   
+  }
+  
 names(sol)<-c("Share the ordering costs rule (individually)")
 }
 return(sol)
